@@ -5,25 +5,24 @@
 # The full license is in the LICENSE file, distributed with this software.
 #-----------------------------------------------------------------------------
 import collections
-import entrypoints
 import inspect
 import logging
 import os
 import warnings
 
-from fsspec import open_files, get_filesystem_class
+import entrypoints
+from fsspec import get_filesystem_class, open_files
 from fsspec.core import split_protocol
 
 from .. import __version__
-from .base import Catalog, DataSource
-from . import exceptions
-from .entry import CatalogEntry
-from ..source import register_driver
-from ..source import get_plugin_class
+from ..source import get_plugin_class, register_driver
 from ..source.discovery import load_plugins_from_module
-from .utils import (expand_defaults, coerce, COERCION_RULES, merge_pars,
-                    _has_catalog_dir)
-from ..utils import yaml_load, DictSerialiseMixin, make_path_posix, classname
+from ..utils import DictSerialiseMixin, classname, make_path_posix, yaml_load
+from . import exceptions
+from .base import Catalog, DataSource
+from .entry import CatalogEntry
+from .utils import (COERCION_RULES, _has_catalog_dir, coerce, expand_defaults,
+                    merge_pars)
 
 logger = logging.getLogger('intake')
 
@@ -43,7 +42,7 @@ class UserParameter(DictSerialiseMixin):
     description: str
         narrative text
     type: str
-        one of list``(COERSION_RULES)``
+        one of list ``(COERSION_RULES)``
     default: type value
         same type as ``type``. It a str, may include special functions
         env, shell, client_env, client_shell.
@@ -56,7 +55,7 @@ class UserParameter(DictSerialiseMixin):
                  min=None, max=None, allowed=None):
         self.name = name
         self.description = description
-        self.type = type
+        self.type = type or __builtins__["type"](default).__name__
         self.min = min
         self.max = max
         self.allowed = allowed
@@ -74,7 +73,7 @@ class UserParameter(DictSerialiseMixin):
         if self.max:
             self.max = coerce(self.type, self.max)
 
-        if self.allowed:
+        if self.allowed and type != "mlist":
             self.allowed = [coerce(self.type, item)
                             for item in self.allowed]
 
@@ -111,6 +110,12 @@ class UserParameter(DictSerialiseMixin):
         if self.type is not None:
             value = coerce(self.type, value)
 
+        if self.type == "mlist":
+            for v in value:
+                if v not in self.allowed:
+                    raise ValueError("Item %s not in allowed list", v)
+            return value
+
         if self.min is not None and value < self.min:
             raise ValueError('%s=%s is less than %s' % (self.name, value,
                                                         self.min))
@@ -686,6 +691,12 @@ class YAMLFileCatalog(Catalog):
         cfg = result.data
 
         self._entries = {}
+        shared_parameters = data.get("metadata", {}).get("parameters", {})
+        self.user_parameters.update({
+            name: UserParameter(name, **attrs)
+            for name, attrs in shared_parameters.items()
+        })
+
         for entry in cfg['data_sources']:
             entry._catalog = self
             self._entries[entry.name] = entry
@@ -768,11 +779,14 @@ class YAMLFilesCatalog(Catalog):
             if f.path not in self._cats:
                 entry = LocalCatalogEntry(name, "YAML file: %s" % name,
                                           'yaml_file_cat', True,
-                                          kwargs, [], {}, self.metadata, d)
+                                          kwargs, [], [], self.metadata, d)
                 if self._flatten:
                     # store a concrete Catalog
                     try:
-                        self._cats[f.path] = entry()
+                        cat = entry()
+                        cat.reload()
+                        self.user_parameters.update(cat.user_parameters)
+                        self._cats[f.path] = cat
                     except IOError as e:
                         logger.info('Loading "%s" as a catalog failed: %s'
                                     '' % (entry, e))
@@ -792,7 +806,7 @@ class YAMLFilesCatalog(Catalog):
                 entries.update(entry._entries)
             else:
                 entries[entry._name] = entry
-        self._entries = entries
+        self._entries.update(entries)
 
 
 class MergedCatalog(Catalog):
