@@ -5,6 +5,8 @@
 # The full license is in the LICENSE file, distributed with this software.
 #-----------------------------------------------------------------------------
 
+import ast
+from collections.abc import Iterable
 import functools
 import itertools
 from jinja2 import Environment, meta, Undefined
@@ -278,11 +280,15 @@ def coerce_datetime(v=None):
 COERCION_RULES = {
     'bool': bool,
     'datetime': coerce_datetime,
+    'dict': dict,
     'float': float,
+    'tuple': tuple,
+    'mlist': list,
     'int': int,
     'list': list,
     'str': str,
-    'unicode': str
+    'unicode': str,
+    'other': lambda x: x
 }
 
 
@@ -295,12 +301,33 @@ def coerce(dtype, value):
     type constructor is returned. Otherwise, the type constructor converts
     and returns the value.
     """
+    if "[" in dtype:
+        dtype, inner = dtype.split("[")
+        inner = inner.rstrip("]")
+    else:
+        inner = None
     if dtype is None:
         return value
     if type(value).__name__ == dtype:
         return value
+    if dtype == "mlist":
+        if isinstance(value, (tuple, set, dict)):
+            return list(value)
+        if isinstance(value, str):
+            try:
+                value = ast.literal_eval(value)
+                return list(value)
+            except ValueError as e:
+                raise ValueError("Failed to coerce string to list") from e
+        return value
     op = COERCION_RULES[dtype]
-    return op() if value is None else op(value)
+    out = op() if value is None else op(value)
+    if isinstance(out, dict) and inner is not None:
+        # TODO: recurse into coerce here, to allow list[list[str]] and such?
+        out = {k: COERCION_RULES[inner](v) for k, v in out.items()}
+    if isinstance(out, (tuple, list, set)) and inner is not None:
+        out = op(COERCION_RULES[inner](v) for v in out)
+    return out
 
 
 class RemoteCatalogError(Exception):
