@@ -4,10 +4,13 @@
 #
 # The full license is in the LICENSE file, distributed with this software.
 #-----------------------------------------------------------------------------
-import pytest
 import os
-from intake.utils import make_path_posix, no_duplicate_yaml
+import posixpath
+import shutil
+
+import pytest
 import yaml
+from intake.utils import make_path_posix, no_duplicate_yaml
 
 
 def test_windows_file_path():
@@ -45,3 +48,15 @@ def test_yaml_tuples():
     text = yaml.dump(data)
     with no_duplicate_yaml():
         assert yaml.safe_load(text) == data
+
+def copy_test_file(filename, target_dir):
+    if not os.path.exists(target_dir):
+        os.makedirs(target_dir)  # can't use exist_ok in Python 2.7
+    target_dir = make_path_posix(target_dir)
+    # Put a catalog file in the user catalog directory
+    test_dir = make_path_posix(os.path.dirname(__file__))
+    test_catalog = posixpath.join(test_dir, filename)
+    target_catalog = posixpath.join(target_dir, '__unit_test_'+filename)
+
+    shutil.copyfile(test_catalog, target_catalog)
+    return target_catalog
